Off[General::spell]

Model`Name = "E6SSMalt";
Model`NameLaTeX ="E6SSMalt";
Model`Authors = "G.Hellwig, P.Diessner, P.Athron, A.Voigt";
Model`Date = "2014-03-10";

(*-------------------------------------------*)
(*   Particle Content*)
(*-------------------------------------------*)

(* Global symmetries *)

Global[[1]] = {Z[2],RParity};
RpM = {-1,-1,1};
RpP = {1,1,-1};

(* Vector Superfields *)

Gauge[[1]]={B,   U[1], hypercharge, g1,False,RpM};
Gauge[[2]]={WB, SU[2], left,        g2,True, RpM};
Gauge[[3]]={G,  SU[3], color,       g3,False,RpM};
Gauge[[4]]={Bp,  U[1], Ncharge,    gN,False,RpM};

(* Chiral Superfields *)

SuperFields[[1]] = {q, 3, {uL,  dL},     1/6, 2, 3, 1/Sqrt[40], RpM};  
SuperFields[[2]] = {l, 3, {vL,  eL},    -1/2, 2, 1, 2/Sqrt[40], RpM};
SuperFields[[3]] = {Hd,1, {Hd0, Hdm},   -1/2, 2, 1, -3/Sqrt[40], RpP};
SuperFields[[4]] = {Hu,1, {Hup, Hu0},    1/2, 2, 1, -2/Sqrt[40], RpP};

SuperFields[[5]] = {d, 3, conj[dR],    1/3, 1, -3, 2/Sqrt[40], RpM};
SuperFields[[6]] = {u, 3, conj[uR],   -2/3, 1, -3, 1/Sqrt[40], RpM};
SuperFields[[7]] = {e, 3, conj[eR],      1, 1,  1, 1/Sqrt[40], RpM};
SuperFields[[8]] = {s, 1, sR,     0, 1,  1, 5/Sqrt[40], RpP};

SuperFields[[9]] = {H1I, 2, {H1I0, H1Im},  -1/2, 2, 1, -3/Sqrt[40], RpP};
SuperFields[[10]] = {H2I, 2, {H2Ip, H2I0},   1/2, 2, 1, -2/Sqrt[40], RpP};
SuperFields[[11]] = {sI, 1, sIR,    0, 1,  1, 5/Sqrt[40], RpP};

SuperFields[[12]] = {Dx1, 1, Dx1L,  -1/3, 1, 3, -2/Sqrt[40], RpP};
SuperFields[[13]] = {Dxbar1, 1, conj[Dxbar1R],  1/3, 1, -3, -3/Sqrt[40], RpP};

SuperFields[[14]] = {Dx2, 1, Dx2L,  -1/3, 1, 3, -2/Sqrt[40], RpP};
SuperFields[[15]] = {Dxbar2, 1, conj[Dxbar2R],  1/3, 1, -3, -3/Sqrt[40], RpP};

SuperFields[[16]] = {Dx3, 1, Dx3L,  -1/3, 1, 3, -2/Sqrt[40], RpP};
SuperFields[[17]] = {Dxbar3, 1, conj[Dxbar3R],  1/3, 1, -3, -3/Sqrt[40], RpP};

SuperFields[[18]] = {Hp, 1, {Hpd0, Hpdm},  -1/2, 2,  1, 2/Sqrt[40], RpP};
SuperFields[[19]] = {Hpbar, 1, {Hpup, Hpu0}, 1/2, 2,  1, -2/Sqrt[40], RpP};
SuperFields[[20]] = {sp, 1, spR,    0, 1,  1, 5/Sqrt[40], RpP};
NoU1Mixing=True;
AddMixedSofts = False;

(*------------------------------------------------------*)
(*Z2H exact Superpotential *)
(*------------------------------------------------------*)

SuperPotential = Yu u.q.Hu - Yd d.q.Hd - Ye e.l.Hd + \[Lambda] s.Hu.Hd + \[Lambda]p sp.Hu.Hd + \[Lambda]12 s.H2I.H1I + \[Lambda]p12 sp.H2I.H1I + \[Kappa]1 s.Dx1.Dxbar1 + \[Kappa]2 s.Dx2.Dxbar2 +  \[Kappa]3 s.Dx3.Dxbar3 + \[Kappa]p1 sp.Dx1.Dxbar1 + \[Kappa]p2 sp.Dx2.Dxbar2 + \[Kappa]p3 sp.Dx3.Dxbar3 + \[Mu]Pr Hpbar.Hp + gQL1 Dx1.q.q + gQL2 Dx2.q.q  + gQL3 Dx3.q.q + gqr1 Dxbar1.d.u+ gqr2 Dxbar2.d.u+ gqr3 Dxbar3.d.u;

(*-------------------------------------------*)
(* Integrate Out or Delete Particles         *)
(*-------------------------------------------*)

IntegrateOut={};
DeleteParticles={};


(*----------------------------------------------*)
(*   ROTATIONS                                  *)
(*----------------------------------------------*)

NameOfStates={GaugeES, EWSB};

(* ----- Before EWSB ----- *)

DEFINITION[GaugeES][DiracSpinors]={
  Bino ->{fB, conj[fB]},
  Wino -> {fWB, conj[fWB]},
  Glu -> {fG, conj[fG]},
  (*  H0 -> {FHd0, conj[FHu0]},
   HC -> {FHdm, conj[FHup]}, *)
  H01 -> {FHd0, 0},
  H02 -> {0, conj[FHu0]},
  HC1 -> {FHdm, 0},
  HC2 -> {0, conj[FHup]},
  Fd1 -> {FdL, 0},
  Fd2 -> {0, FdR},
  Fu1 -> {FuL, 0},
  Fu2 -> {0, FuR},
  Fe1 -> {FeL, 0},
  Fe2 -> {0, FeR},
  Fv -> {FvL,0},
  FS1 -> {FsR,0},
  FS2 -> {0,conj[FsR]},
  FSp1 -> {FspR,0},
  FSp2 -> {0,conj[FspR]},
  FBp -> {fBp,conj[fBp]},
  (* HI0 -> {FH1I0, conj[FH2I0]},
   HIC -> {FH1Im, conj[FH2Ip]}, *)
  H0I1 -> {FH1I0, 0},
  H0I2 -> {0, conj[FH2I0]},
  HCI1 -> {FH1Im, 0},
  HCI2 -> {0, conj[FH2Ip]},
  (* It seems SI needs to be a EWSB state
   SI -> {FsIR, conj[FsIR]}, *)
  FSI1 -> {FsIR, 0},
  FSI2 -> {0, conj[FsIR]},
  FDx11 -> {FDx1L, 0},
  FDx12 -> {0, FDxbar1R},
  FDx21 -> {FDx2L, 0},
  FDx22 -> {0, FDxbar2R},
  FDx31 -> {FDx3L, 0},
  FDx32 -> {0, FDxbar3R},
  (* Hp0 -> {FHpd0, conj[FHpu0]},
   HpC -> {FHpdm, conj[FHpup]} *)
  Hp01 -> {FHpd0, 0},
  Hp02 -> {0, conj[FHpu0]},
  HpC1 -> {FHpdm, 0} ,
  HpC2 -> {0, conj[FHpup]} 
};


(* ----- After EWSB ----- *)


(* Gauge Sector *)

DEFINITION[EWSB][GaugeSector] =
{ 
   {{VB,VWB[3],VBp},{VP,VZ,VZp},ZZ},
  {{VWB[1],VWB[2]},{VWm,conj[VWm]},ZW},
  {{fWB[1],fWB[2],fWB[3]},{fWm,fWp,fW0},ZfW}
};      
          	

(* ----- VEVs ---- *)

DEFINITION[EWSB][VEVs]= 
  { {SHd0, {vd, 1/Sqrt[2]}, {sigmad, \[ImaginaryI]/Sqrt[2]},{phid,1/Sqrt[2]}},
    {SHu0, {vu, 1/Sqrt[2]}, {sigmau, \[ImaginaryI]/Sqrt[2]},{phiu,1/Sqrt[2]}},
    {SsR,  {vs, 1/Sqrt[2]}, {sigmaS, \[ImaginaryI]/Sqrt[2]},{phiS,1/Sqrt[2]}},
    {SspR,  {vsp, 1/Sqrt[2]}, {sigmaSp, \[ImaginaryI]/Sqrt[2]},{phiSp,1/Sqrt[2]}}   
};


 
(* ---- Mixings ---- *)

DEFINITION[EWSB][MatterSector]= 
{    {{SdL, SdR}, {Sd, ZD}},
     {{SvL}, {Sv, ZV}},
     {{SuL, SuR}, {Su, ZU}},
     {{SeL, SeR}, {Se, ZE}},
     {{SDx1L, SDxbar1R}, {SDX1, ZDX1}},
     {{SDx2L, SDxbar2R}, {SDX2, ZDX2}},
     {{SDx3L, SDxbar3R}, {SDX3, ZDX3}},
     {{phid, phiu, phiS, phiSp}, {hh, ZH}},
     {{sigmad, sigmau, sigmaS, sigmaSp}, {Ah, ZA}},
     {{SHdm,conj[SHup]},{Hpm,ZP}},
     {{fB, fW0, FHd0, FHu0, FsR, fBp, FspR}, {L0, ZN}}, 
     {{{fWm, FHdm}, {fWp, FHup}}, {{Lm,UM}, {Lp,UP}}}, 
     {{{FeL},{conj[FeR]}},{{FEL,ZEL},{FER,ZER}}},
     {{{FdL},{conj[FdR]}},{{FDL,ZDL},{FDR,ZDR}}},
     {{{FuL},{conj[FuR]}},{{FUL,ZUL},{FUR,ZUR}}},
     {{{FDx1L},{conj[FDxbar1R]}},{{FDX1L,ZDX1L},{FDX1R,ZDX1R}}},
     {{{FDx2L},{conj[FDxbar2R]}},{{FDX2L,ZDX2L},{FDX2R,ZDX2R}}},	
     {{{FDx3L},{conj[FDxbar3R]}},{{FDX3L,ZDX3L},{FDX3R,ZDX3R}}},	
     {{SH1I0,conj[SH2I0]},{SHI0,UHI0}},
     {{SH1Im,conj[SH2Ip]},{SHIp,UHIp}},
     {{{FH1Im},{FH2Ip}},{{LmI,ZMI},{LpI,ZPI}}},
     {{FH1I0,FH2I0},{L0I,ZNI}},
     {{SsIR},{SSI0,ZSSI}},
     {{FsIR},{LS0I,ZFSI}},
     {{SHpd0,conj[SHpu0]},{SHp0,UHp0}},
     {{SHpdm,conj[SHpup]},{SHpp,UHpp}},
     {{FHpd0,FHpu0},{L0p,ZNp}}
     (* {{FH1Im,FH2Ip},{LPI,ZNp}} *)
}; 
       
DEFINITION[EWSB][Phases]= 
   {    {fG, PhaseGlu},
        {ChaP, PhaseFHpup}
}; 

DEFINITION[EWSB][DiracSpinors]={
 Fd -> {FDL, conj[FDR]},
 Fe -> {FEL, conj[FER]},
 Fu -> {FUL, conj[FUR]},
 Fv -> {FvL, 0},
 Chi -> {L0, conj[L0]},
 Cha -> {Lm, conj[Lp]},
 Glu -> {fG, conj[fG]},
 ChiI -> {L0I, conj[L0I]},
 ChaI -> {LmI, conj[LpI]},
 (* ChaI -> {LPI, conj[LPI]}, *)
 (* no EWSB contribution to survivals 
  but still need to specify Dirac state*)
 ChiP -> {L0p, conj[L0p]},
 ChaP -> {FHpdm, conj[FHpup]}, 
 (*FDX -> {FDxL, conj[FDxbarR]}*)
 FDX1 -> {FDX1L, conj[FDX1R]},
 FDX2 -> {FDX2L, conj[FDX2R]},
 FDX3 -> {FDX3L, conj[FDX3R]},
 FSI -> {LS0I, conj[LS0I]}
};	
